analyse - a powerful staock data analysis and manipulation library for Python
=================================================================================

**analyse** is a Python package providing fast, flexible, and expressive data
structures designed to analyse stock both in hongkong,us,china market,it has
the broader goal of becoming **the most powerful and flexible open source data
analysis / manipulation tool in analyzing stock**. It is already well on
its way toward this goal.

Main Features
-------------
Here are just a few of the things that analyse does well:

  -get raw data from tdx 
  -calculate pe,pe_ttm
  -calculate growth
  -calculate current vix
